@@ -1,5 +1,5 @@
 /// name = "light_phylogeny"
-/// version = "0.10.0"
+/// version = "0.19.0"
 /// authors = ["Simon Penel <simon.penel@univ-lyon1.fr>"]
 /// license = "CECILL-2.1"
 use log::{info};
@@ -203,10 +203,23 @@ pub fn draw_sptree_gntrees (
                                            config.species_opacity.to_string());
                 if sp_tree.arena[p].visible {
                     g.append(chemin)
-                };                           
+                };
                 if sp_tree.is_leaf(index.idx) {
+                    // Set the y value of the pipe leaf ro the highest value of the y gene leaves
+                    let mut max_gene_y =  index.y;
+                    for (gene_index, gene_node ) in &index.nodes {
+                        let gene_y = gene_trees[*gene_index].arena[*gene_node].y;
+                        if  gene_trees[*gene_index].arena[*gene_node].e != Event::Loss {
+                            if gene_y >  max_gene_y {
+                                max_gene_y = gene_y;
+                            }
+                        }
+                    };
+                    if max_gene_y == index.y {
+                         max_gene_y = max_gene_y +index.height / 2.0;
+                    }
                     let chemin = close_chemin_sp(index.x, index.y,
-                                                 index.width/2.0, index.height/2.0,
+                                                 index.width/2.0, max_gene_y - index.y,
                                                  config.species_color.to_string(),
                                                  config.species_opacity.to_string());
                     g.append(chemin);
@@ -400,13 +413,13 @@ pub fn draw_sptree_gntrees (
             match event {
                 Event::Leaf        => {
                     let mut element = Element::new("text");
-                    element.assign("x", index.x+10.0);
-                    element.assign("y", index.y+0.0);
+                    element.assign("x", index.x - 5.0);
+                    element.assign("y", index.y + 15.0);
                     element.assign("class", "gene_".to_owned()+&idx_rcgen.to_string());
                     let txt  = Text::new(&index.name);
                     element.append(txt);
-                    element.assign("transform","rotate(90 ".to_owned() + &index.x.to_string()
-                    + "," + &index.y.to_string() + ")" );
+                    element.assign("transform","rotate(90 ".to_owned() + &(index.x - 5.0).to_string()
+                    + "," + &(index.y + 15.0).to_string() + ")" );
                     g.append(element);
                     },
                 _ => {
@@ -699,8 +712,8 @@ pub fn get_chemin_sp (x1: f32, y1:f32, width1:f32, height1:f32, x2: f32, y2:f32,
 pub fn close_chemin_sp (x1: f32, y1:f32, width1:f32, height1:f32, c:String, o:String ) -> Path {
         let data = Data::new()
         .move_to((x1 - width1, y1 - height1))
-        .line_to((x1 - width1, y1 + 2.0 * height1))
-        .line_to((x1 + width1, y1 + 2.0 * height1))
+        .line_to((x1 - width1, y1 + 1.0 * height1))
+        .line_to((x1 + width1, y1 + 1.0 * height1))
         .line_to((x1 + width1, y1 - height1));
         let path = Path::new()
         .set("fill", "none")
